.. _release:

*************
Release notes
*************

This is the list of changes to :code:`watex` between each release. For full details,
see the `commit logs <https://github.com/WEgeophysics/watex/commits/>`_.


Version 0.1
-------------

.. toctree::
   :maxdepth: 2
   
   v0.1.9
   v0.1.8
   v0.1.7
   v0.1.6
   v0.1.6-alpha
   v0.1.5
   v0.1.4
   v0.1.3
   v0.1.2
   v0.1.1
   v0.1.0
